/*
 * Copyright (c) 2009 by syntevo GmbH. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of syntevo GmbH nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.syntevo.openapi.gui;

import java.awt.*;
import java.util.List;

import com.syntevo.openapi.gui.dialog.*;
import com.syntevo.openapi.gui.editor.*;
import com.syntevo.openapi.gui.table.*;

/**
 * This class provides factory methods for GUI components.
 * You must call methods of this class only from within the EventDispatchThread.
 * Use GuiUtils.executeInEventDispatchThread() for this purpose.
 * @deprecated
 */
public interface GuiComponentFactory {

	/**
	 * Creates a sorted table with the specified columns.
	 *
	 * @param columns  a list of ITableColumn objects which define the columns for the table
	 * @param parent the parent panel
	 */
	<RO> SortedTable<RO> createTable(List<ITableColumn<RO>> columns, Container parent);

	/**
	 * Creates a FileEditor.
	 *
	 * @param labelText  the label text
	 * @param pattern  the file pattern filter
	 * @param patternTitle  the title of the file pattern
	 * @param dialogDisplayer  a DialogDisplayer which is used to display the File-Open dialog
	 * @param parent the parent panel
	 */
	FileEditor createFileOpenEditor(String labelText, String pattern, String patternTitle, DialogDisplayer dialogDisplayer, Container parent);

	/**
	 * Creates a password input field editor (not displaying characters).
	 *
	 * @param labelText the label text
	 * @param parent the parent panel
	 */
	TextFieldEditor createPasswordEditor(String labelText, Container parent);

	/**
	 * Creates a basic text input field editor.
	 *
	 * @param labelText the label text
	 * @param parent the parent panel
	 */
	TextFieldEditor createTextFieldEditor(String labelText, Container parent);

	/**
	 * Creates a MnemonicManager.
	 */
	MnemonicManager createMnemonicManager();
}
