/*
 * Copyright (c) 2009 by syntevo GmbH. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of syntevo GmbH nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.syntevo.openapi.smartsvn.command.commit;

import com.syntevo.openapi.gui.dialog.*;
import com.syntevo.openapi.smartsvn.command.*;
import com.syntevo.openapi.smartsvn.file.*;
import com.syntevo.openapi.smartsvn.thread.*;

/**
 * Services for ICommitMessageSource objects.
 */
public interface CommitMessageSourceServices {

	/**
	 * Returns the common path of the files/directories to be committed (resp. part of the Change Set)
	 * for which the ICommitMessageSource shall produce messages.
	 */
	Path getCommitRootPath();

	/**
	 * Returns a DialogDisplayer to be used by the ICommitMessageSource, if needed.
	 */
	DialogDisplayer getDialogDisplayer();

	/**
	 * Returns a {@link com.syntevo.openapi.smartsvn.thread.JobExecutor} to be used by the workflow for the packet phases.
	 * Jobs will be run in a background thread without any relation to the GUI.
	 */
	JobExecutor getJobExecutor();

	/**
	 * Returns SvnClients to be used by the ICommitMessageSource, if needed.
	 * The SvnClients are valid until created ICommitMessageSource objects have been cleaned up.
	 */
	SvnClients getClients();
}
