/*
 * Copyright (c) 2002-2009 syntevo GmbH. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of syntevo GmbH nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.syntevo.q.gui.layout;

import java.awt.*;
import java.util.*;
import java.util.List;

/**
 * @author Thomas Singer
 */
final class TableGridColumnOrRow {

	// Fields =================================================================

	private final int size;
	private final TableGridStretchValue stretchValue;
	private final TableGridGroup group;
	private List<Component> components;

	// Setup ==================================================================

	public TableGridColumnOrRow(int size, TableGridStretchValue stretchValue, TableGridGroup group) {
		if (stretchValue == null) {
			throw new NullPointerException("stretchValue must not be null");
		}

		this.size = size;
		this.stretchValue = stretchValue;
		this.group = group;

		if (group != null) {
			group.add(this);
		}
	}

	// Implemented ============================================================

	@Override
	public String toString() {
		return "size = " + size + ", stretch = " + stretchValue + ", components = " + components;
	}

	// Accessing ==============================================================

	public int getSize() {
		return size;
	}

	public TableGridStretchValue getStretchValue() {
		return stretchValue;
	}

	public Collection<Component> getComponents() {
		if (components == null) {
			return Collections.emptyList();
		}
		return components;
	}

	public Collection<Component> getGroupingComponents() {
		if (group == null) {
			return getComponents();
		}

		return group.getComponents();
	}

	public void addComponent(Component component) {
		if (components == null) {
			components = new ArrayList<Component>();
		}
		components.add(component);
		if (group != null) {
			group.invalidateCache();
		}
	}

	public void removeComponent(Component comp) {
		if (components != null) {
			components.remove(comp);
		}
		if (group != null) {
			group.invalidateCache();
		}
	}
}
