package com.syntevo.plugin.sendsupportemail;

import java.awt.*;
import java.io.*;
import java.net.*;

import com.syntevo.openapi.smartsvn.action.*;

/**
 * @author syntevo GmbH
 */
final class SendSupportEmailAction implements ISvnAction {

	// Constants ==============================================================

	public static final String ID = SendSupportEmailPlugin.ID + ".SendSupportEmail";

	// Setup ==================================================================

	public SendSupportEmailAction() {
	}

	// Implemented ============================================================

	public boolean isApplicable(boolean isProjectOpen) {
		return true;
	}

	public void execute(ActionServices services) {
		final StringBuilder buffer = new StringBuilder();
		buffer.append("mailto:support@smartsvn.com?SUBJECT=");
		uriEncode("Feedback for SmartSVN " + System.getProperty("smartsvn.versionString"), buffer);
		buffer.append("&BODY=");
		uriEncode("System Details\n", buffer);
		appendVmProperty("os.name", buffer);
		appendVmProperty("os.version", buffer);
		appendVmProperty("java.runtime.name", buffer);
		appendVmProperty("java.runtime.version", buffer);
		appendVmProperty("smartsvn.home", buffer);

		try {
			Desktop.getDesktop().mail(new URI(buffer.toString()));
			return;
		}
		catch (URISyntaxException ex) {
			SendSupportEmailPlugin.LOG.error("Could not open email client", ex);
		}
		catch (IOException ex) {
			SendSupportEmailPlugin.LOG.error("Could not open email client", ex);
		}
		catch (UnsupportedOperationException ex) {
			SendSupportEmailPlugin.LOG.error("Could not open email client", ex);
		}
		catch (SecurityException ex) {
			SendSupportEmailPlugin.LOG.error("Could not open email client", ex);
		}

		services.getDialogDisplayer().showErrorDialog("Contact Support", "Could not open the system e-mail client.", "Please send the e-mail to support@smartsvn.com.");
	}

	// Utils ==================================================================

	private void appendVmProperty(String propertyName, StringBuilder buffer) {
		uriEncode(propertyName, buffer);
		uriEncode(": ", buffer);
		uriEncode(System.getProperty(propertyName), buffer);
		uriEncode("\n", buffer);
	}

	private void uriEncode(String text, StringBuilder buffer) {
		if (text == null) {
			return;
		}

		final byte[] bytes;
		try {
			bytes = text.getBytes("UTF-8");
		}
		catch (UnsupportedEncodingException ex) {
			SendSupportEmailPlugin.LOG.error("Could not encode URI", ex);
			return;
		}

		for (final byte value : bytes) {
			if (isValidUriChar(value)) {
				buffer.append((char)value);
				continue;
			}

			buffer.append('%');
			appendHexDigit(value >> 4, buffer);
			appendHexDigit(value, buffer);
		}
	}

	private void appendHexDigit(int value, StringBuilder buffer) {
		value &= 0xF;
		buffer.append("0123456789ABCDEF".charAt(value));
	}

	private static boolean isValidUriChar(byte value) {
		if (value <= 0x20 || value >= 0x7F) {
			return false;
		}

		if (value >= 0x26 && value <= 0x3A) {
			return true;
		}

		if (value == 0x21 || value == 0x24 || value == 0x3D || value == 0x5F || value == 0x7E) {
			return true;
		}

		if (value >= 0x40 && value <= 0x5A) {
			return true;
		}

		return value >= 0x61 && value <= 0x7A;
	}
}
